//********************* sx12f.h ***************************
//* This file contains sx12.dll functions declarations
//* for use with Sensoray model 512 MPEG codec.
//* Copyright (C) Sensoray 2001
//*********************************************************

#ifndef XFUNCX12
//Pointers to DLL functions
#define XFUNCX12(RTNTYPE,FUNCNAME)	extern RTNTYPE (__stdcall *FUNCNAME)
#endif


#ifdef __cplusplus
extern "C" {
#endif

//DLL load/unload functions
extern int X12_DLLOpen(void);
extern void X12_DLLClose(void);


//Pointers to sx12.dll exported functions

// Resets the 512
XFUNCX12(int, X12_reset)(int CardId);

// Select video input, i.e. 0-4
XFUNCX12(void, X12_set_input)(int CardId,int input);

// Sets video input type, i.e. SVIDEO (1) or CVIDEO (0)
XFUNCX12(void, X12_set_input_type)(int CardId,int type);

// Set video system, i.e. NTSC (2) or PAL (1) 
XFUNCX12(void, X12_set_system)(int CardId,int system);

// Set desired bit rate, typically 700,000 to 10,000,000
XFUNCX12(void, X12_set_bitrate)(int CardId,int rate);

// Set picture size and compression system 
// D1 MPEG-2 (0), 1/2 D1 MPEG-2 (1),       
// 2/3 D1 MPEG-2 (2), or CIF MPEG-1 (3)    
XFUNCX12(void, X12_set_picsize)(int CardId,int size);

// Sets number of frames in Group of Pictures 
XFUNCX12(void, X12_set_m)(int CardId,int m);

// Sets distance between I/P frames 
XFUNCX12(void, X12_set_n)(int CardId,int n);

// Enables (1)/disables (0) variable bit rate compression
XFUNCX12(void, X12_set_vbr)(int CardId,int vbr);

// Reads state of GPIO pins: active low inputs
// when input pulled down bit is set to 1
XFUNCX12(int, X12_read_gpio)(int CardId);

// Sets state of GPIO pins: active low outputs when bit is set to 1
XFUNCX12(void, X12_write_gpio)(int CardId,int state);

// Returns compression frame count
XFUNCX12(int, X12_get_framecount)(int CardId);

// Returns decompression frame count
XFUNCX12(int, X12_get_displayframecount)(int CardId);

// Returns number of dropped frames during compression
XFUNCX12(int, X12_get_droppedframes)(int CardId);

// Returns amount of data in video queue
XFUNCX12(int, X12_get_vqsize)(int CardId);

// Returns I/O port
XFUNCX12(int, X12_get_port)(int CardId);

// Read method - Attempts to read "nbytes" bytes of MPEG data from the
//SM2210 output fifo. The actual ammount read is returned. If no data
//is available -1 is returned unless blocking has been enabled. In
//which case this function will wait until at least one byte of data is
//made available. If this is the first read the encoder is initialized
//and started.
XFUNCX12(int, X12_read)(int CardId,char *buffer,int nbytes);

// Write method - Attempts to write "nbytes" bytes of MPEG data to the
//SM2210 input fifo. The actual ammount written is returned. If this
//is the first write the decoder is initialized and started.
XFUNCX12(int, X12_write)(int CardId,char *buffer,int nbytes);

// Open method
//XFUNCX12(int, X12_open)(int CardId);

// Close method
//XFUNCX12(void, X12_close)(int CardId);

// Init module. It checks base addresses, number of 512s, etc.
// Returns:
// -1  - driver open error
// >=0 - number of cards
XFUNCX12(int, X12_init)(void);

// This is called when the module is unloaded
XFUNCX12(void, X12_cleanup)(void);


#ifdef __cplusplus
}
#endif

